# Documentation for your first returned item: VCalendar

Once you imported the iCal-library library, you can use either the `client` or `CacheCLient` to get a `VCalendar` object.
This page explains all the functions and attributes of the `VCalendar` object.

::: ical_library.ical_components.VCalendar
